# Sage version information for shell scripts.
#
# #31049: The following line is valid shell code but not valid Python code,
# which stops "setup.py develop" from rewriting it as a Python file.
:
# This file is auto-generated by the update-version script, do not edit!
SAGE_VERSION='10.6.29'
SAGE_RELEASE_DATE='2025-09-29'
SAGE_VERSION_BANNER='passagemath version 10.6.29, Release Date: 2025-09-29'
